""" 
 *  Copyright Synerty Pty Ltd 2016
 *
 *  This software is proprietary, you are not free to copy
 *  or redistribute this code in any format.
 *
 *  All rights to this software are reserved by 
 *  Synerty Pty Ltd
 *
"""

import logging

from sqlalchemy import Column
from sqlalchemy import Index
from sqlalchemy import Integer
from sqlalchemy import String
from sqlalchemy import orm
from sqlalchemy.sql.sqltypes import DateTime
from vortex.Tuple import Tuple
from vortex.Tuple import addTupleType

from peek_plugin_inbox._private.PluginNames import inboxTuplePrefix
from peek_plugin_inbox._private.storage.DeclarativeBase import DeclarativeBase

logger = logging.getLogger(__name__)


@addTupleType
class Activity(DeclarativeBase, Tuple):
    """Activity

    An Activity represents an item in the activity screen
    This is a screen that is intended to show actions that have been performed recently
        or events that plugins want in this list.

    see InboxAbiABC.NewActivity for documentation.

    """

    __tupleType__ = inboxTuplePrefix + "Activity"
    __tablename__ = "Activity"

    id = Column(Integer, primary_key=True, autoincrement=True)

    pluginName = Column(String, nullable=False)
    uniqueId = Column(String, nullable=False)
    userId = Column(String, nullable=False)
    dateTime = Column(DateTime(True), nullable=False)

    # The display properties of the task
    title = Column(String, nullable=False)
    description = Column(String)
    iconPath = Column(String)

    # The mobile-app route to open when this task is selected
    routePath = Column(String)
    routeParamJson = Column(String)

    # Auto Delete on Time
    autoDeleteDateTime = Column(DateTime(True), nullable=False)

    __table_args__ = (
        Index(
            "idx_Activity_pluginName_uniqueId",
            pluginName,
            uniqueId,
            unique=True,
        ),
    )

    @orm.reconstructor
    def __init__(self, **kwargs):
        Tuple.__init__(self, **kwargs)



import logging
from datetime import datetime

from peek_plugin_inbox._private.PluginNames import inboxTuplePrefix
from vortex.Tuple import Tuple, addTupleType, TupleField

logger = logging.getLogger(__name__)


@addTupleType
class ActivityTuple(Tuple):
    """Activity Tuple

    An Activity represents an item in the activity screen.
    This is a screen that is intended to show actions that have been performed recently
    or events that plugins want in this list.

    See InboxAbiABC.NewActivity for detailed documentation.

    Attributes:
        pluginName (str): The name of the plugin creating this activity.
        uniqueId (str): A unique identifier for this activity.
        userId (str): The user ID associated with this activity.
        dateTime (datetime): The date and time of the activity.
        title (str): The title to display for the activity.
        description (str): The long text displayed under the title.
        iconPath (str): The URL for the icon, if any.
        routePath (str): The mobile-app route to open when this activity is selected.
        routeParamJson (str): JSON-encoded route parameters.
        autoDeleteDateTime (datetime): The time when this activity will be automatically deleted.
    """

    __tupleType__ = inboxTuplePrefix + "ActivityTuple"

    pluginName: str = TupleField()
    uniqueId: str = TupleField()
    userId: str = TupleField()
    dateTime: datetime = TupleField()

    # The display properties of the task
    title: str = TupleField()
    description: str = TupleField()
    iconPath: str = TupleField()

    # The mobile-app route to open when this task is selected
    routePath: str = TupleField()
    routeParamJson: str = TupleField()

    # Auto Delete on Time
    autoDeleteDateTime: datetime = TupleField()



""" 
 *  Copyright Synerty Pty Ltd 2016
 *
 *  This software is proprietary, you are not free to copy
 *  or redistribute this code in any format.
 *
 *  All rights to this software are reserved by 
 *  Synerty Pty Ltd
 *
"""

import logging

from sqlalchemy import Column
from sqlalchemy import Index
from sqlalchemy import Integer
from sqlalchemy import String
from sqlalchemy import orm
from sqlalchemy.orm import relationship
from sqlalchemy.sql.sqltypes import DateTime
from vortex.Tuple import Tuple
from vortex.Tuple import addTupleType

from peek_plugin_base.storage.TypeDecorators import PeekLargeBinary
from peek_plugin_inbox._private.PluginNames import inboxTuplePrefix
from peek_plugin_inbox._private.storage.DeclarativeBase import DeclarativeBase
from peek_plugin_inbox.server.InboxApiABC import NewTask

logger = logging.getLogger(__name__)


@addTupleType
class Task(DeclarativeBase, Tuple):
    """Task

    A Task represents the feature rich messages that can be sent from initiator
    plugins to mobile devices.

    see InboxAbiABC.NewTask for documentation.

    """

    __tupleType__ = inboxTuplePrefix + "Task"
    __tablename__ = "Task"

    # Ensure that the actions are serialised
    __fieldNames__ = ["actions"]

    id = Column(Integer, primary_key=True, autoincrement=True)

    pluginName = Column(String, nullable=False)
    uniqueId = Column(String, nullable=False)
    userId = Column(String, nullable=False)
    dateTime = Column(DateTime(True), nullable=False)

    # The display properties of the task
    title = Column(String, nullable=False)
    description = Column(String)
    iconPath = Column(String)

    # The mobile-app route to open when this task is selected
    routePath = Column(String)
    routeParamJson = Column(String)

    # The confirmation options
    onDeliveredPayloadEnvelope = Column(PeekLargeBinary)
    onCompletedPayloadEnvelope = Column(PeekLargeBinary)
    onDeletedPayloadEnvelope = Column(PeekLargeBinary)
    onDialogConfirmPayloadEnvelope = Column(PeekLargeBinary)

    AUTO_COMPLETE_OFF = NewTask.AUTO_COMPLETE_OFF
    AUTO_COMPLETE_ON_DELIVER = NewTask.AUTO_COMPLETE_ON_DELIVER
    AUTO_COMPLETE_ON_SELECT = NewTask.AUTO_COMPLETE_ON_SELECT
    AUTO_COMPLETE_ON_ACTION = NewTask.AUTO_COMPLETE_ON_ACTION
    AUTO_COMPLETE_ON_DIALOG = NewTask.AUTO_COMPLETE_ON_DIALOG
    autoComplete = Column(Integer, nullable=False, server_default="0")
    autoDeleteDateTime = Column(DateTime(True), nullable=True)

    AUTO_DELETE_OFF = NewTask.AUTO_DELETE_OFF
    AUTO_DELETE_ON_DELIVER = NewTask.AUTO_DELETE_ON_DELIVER
    AUTO_DELETE_ON_SELECT = NewTask.AUTO_DELETE_ON_SELECT
    AUTO_DELETE_ON_ACTION = NewTask.AUTO_DELETE_ON_ACTION
    AUTO_DELETE_ON_COMPLETE = NewTask.AUTO_DELETE_ON_COMPLETE
    AUTO_DELETE_ON_DIALOG = NewTask.AUTO_DELETE_ON_DIALOG
    autoDelete = Column(Integer, nullable=False, server_default="0")

    # The state of this action
    STATE_DELIVERED = 1
    STATE_SELECTED = 2
    STATE_ACTIONED = 4
    STATE_COMPLETED = 8
    STATE_DIALOG_CONFIRMED = 16  # The dialog was achnowledged
    stateFlags = Column(Integer, nullable=False, server_default="0")

    NOTIFY_BY_DEVICE_POPUP = NewTask.NOTIFY_BY_DEVICE_POPUP
    NOTIFY_BY_DEVICE_SOUND = NewTask.NOTIFY_BY_DEVICE_SOUND
    NOTIFY_BY_SMS = NewTask.NOTIFY_BY_SMS
    NOTIFY_BY_EMAIL = NewTask.NOTIFY_BY_EMAIL
    NOTIFY_BY_DEVICE_DIALOG = NewTask.NOTIFY_BY_DEVICE_DIALOG
    notificationRequiredFlags = Column(
        Integer, nullable=False, server_default="0"
    )
    notificationSentFlags = Column(Integer, nullable=False, server_default="0")

    DISPLAY_AS_TASK = NewTask.PRIORITY_SUCCESS
    DISPLAY_AS_MESSAGE = NewTask.PRIORITY_SUCCESS
    displayAs = Column(Integer, nullable=False, server_default="0")

    PRIORITY_SUCCESS = NewTask.PRIORITY_SUCCESS
    PRIORITY_INFO = NewTask.PRIORITY_INFO
    PRIORITY_WARNING = NewTask.PRIORITY_WARNING
    PRIORITY_DANGER = NewTask.PRIORITY_DANGER
    displayPriority = Column(Integer, nullable=False, server_default="0")

    # The actions for this Task.
    actions = relationship("TaskAction", overlaps="task")

    __table_args__ = (
        Index(
            "idx_Task_pluginName_uniqueId", pluginName, uniqueId, unique=True
        ),
    )

    @orm.reconstructor
    def __init__(self, **kwargs):
        Tuple.__init__(self, **kwargs)



""" 
 *  Copyright Synerty Pty Ltd 2016
 *
 *  This software is proprietary, you are not free to copy
 *  or redistribute this code in any format.
 *
 *  All rights to this software are reserved by 
 *  Synerty Pty Ltd
 *
"""

import logging

from sqlalchemy import Column
from sqlalchemy import Integer
from sqlalchemy import String
from sqlalchemy import orm
from sqlalchemy.orm import relationship
from sqlalchemy.sql.schema import ForeignKey
from sqlalchemy.sql.schema import Index
from vortex.Tuple import Tuple
from vortex.Tuple import addTupleType

from peek_plugin_base.storage.TypeDecorators import PeekLargeBinary
from peek_plugin_inbox._private.PluginNames import inboxTuplePrefix
from peek_plugin_inbox._private.storage.DeclarativeBase import DeclarativeBase

logger = logging.getLogger(__name__)


@addTupleType
class TaskAction(DeclarativeBase, Tuple):
    """Task Action

    This table stores the Task Actions.
    Tasks have zero or more actions that can be performed by the user when they
    receive a task.

    :member title: The title of the action, this will appear as a menu option.
    :member confirmMessage: This is the message that will be shown to confirm the action.
    :member actionedPayload: This payload will be delivered locally on Peek Server
        When the action is performed on the user device.

    """

    __tupleType__ = inboxTuplePrefix + "TaskAction"
    __tablename__ = "TaskAction"

    id = Column(Integer, primary_key=True, autoincrement=True)
    taskId = Column(
        Integer, ForeignKey("Task.id", ondelete="CASCADE"), nullable=False
    )
    task = relationship("Task", uselist=False, overlaps="actions")

    title = Column(String)
    confirmMessage = Column(String)
    onActionPayloadEnvelope = Column(PeekLargeBinary)

    __table_args__ = (Index("idx_TaskAction_taskId", taskId, unique=False),)

    @orm.reconstructor
    def __init__(self, **kwargs):
        Tuple.__init__(self, **kwargs)



"""index_userId

Peek Plugin Database Migration Script

Revision ID: 6896549f8918
Revises: 7e6bd0411082
Create Date: 2024-02-26 16:38:03.869873

"""

# revision identifiers, used by Alembic.
revision = "6896549f8918"
down_revision = "7e6bd0411082"
branch_labels = None
depends_on = None

from alembic import op
import sqlalchemy as sa
import geoalchemy2


def upgrade():
    # ### commands auto generated by Alembic - please adjust! ###
    for tableName in ("Task", "Activity"):
        op.create_index(
            index_name=f"idx_{tableName}_userId",
            table_name=tableName,
            columns=["userId"],
            unique=False,
            schema="pl_inbox",
        )
    # ### end Alembic commands ###


def downgrade():
    # ### commands auto generated by Alembic - please adjust! ###
    for tableName in ("Task", "Activity"):
        op.drop_index(
            f"idx_{tableName}_userId", table_name=tableName, schema="pl_inbox"
        )

    # ### end Alembic commands ###



import logging

from peek_plugin_inbox._private.PluginNames import (
    inboxFilt,
    inboxActionProcessorName,
)
from peek_plugin_inbox._private.server.controller.MainController import (
    MainController,
)
from vortex.handler.TupleActionProcessor import TupleActionProcessor

logger = logging.getLogger(__name__)


def makeTupleActionProcessorHandler(inboxProcessor: MainController):
    processor = TupleActionProcessor(
        tupleActionProcessorName=inboxActionProcessorName,
        additionalFilt=inboxFilt,
        defaultDelegate=inboxProcessor,
    )
    return processor
